@@ -4,7 +4,7 @@ import argparse
 import codecs
 import json
 
-from pymongo import json_util
+from bson import json_util
 
 from nlpkit.corenlp import parse_texts
 
@@ -18,7 +18,7 @@ parser.add_argument('--jar-dir', '--jar', help="Path to CoreNLP jar files",
 parser.add_argument('--prop-file', '--prop', help="CoreNLP property file")
 #parser.add_argument('--update', action='store_true', help='Generate a document using update modifiers')
 parser.add_argument('--fields', nargs='*', help="Process only the listed fields")
-parser.add_argument('--cache', help='Cache results from parser')
+parser.add_argument('--cache', action='store_true', help='Cache results from parser')
 args = parser.parse_args()
 
 in_file = codecs.open(args.mongo_file, encoding='utf-8')
