@@ -1,5 +1,5 @@
 # intentionally empty; called on package initialization
-from pymongo.objectid import ObjectId
+from bson.objectid import ObjectId
 
 def new_id():
-    return str(ObjectId())
+    return str(ObjectId())
\ No newline at end of file
